@@ -7,3 +7,6 @@ expect_equal(to_x(90, 1), 0)
 expect_equal(to_y(90, 1), 1)
 expect_equal(to_t(0, 1), 90)
 expect_equal(to_r(0, 1), 1)
+
+f <- function(x) assert_suggested("imaginaryPackage")
+expect_error(f(), "You need to install the suggested package")
